==> xlc_1.0.1.orig.tar.gz: xlc-1.0.1/src/callbacks_xlcm.h <==
#include <gtk/gtk.h>


void
on_wnd_acitivity_realize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_acitivity_unrealize             (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_wnd_activity_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_wnd_activity_button_release_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_mn_popup_show_messages_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_popup_exit_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_wnd_messages_realize                (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_messages_unrealize              (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_bt_msg_close_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_bt_msg_clear_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_mn_popup_realize                    (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_mn_popup_unrealize                  (GtkWidget       *widget,
                                        gpointer         user_data);

==> xlc_1.0.6.orig.tar.gz: xlc-1.0.6/src/callbacks_xlcm.h <==
#include <gtk/gtk.h>


void
on_wnd_acitivity_realize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_acitivity_unrealize             (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_wnd_activity_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_wnd_activity_button_release_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_mn_popup_show_messages_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_mn_popup_exit_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_wnd_messages_realize                (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_messages_unrealize              (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_bt_msg_close_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_bt_msg_clear_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_mn_popup_realize                    (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_mn_popup_unrealize                  (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_askname_unrealize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_wnd_askname_realize                 (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_bt_asknum_ok_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_bt_asknum_cancel_clicked            (GtkButton       *button,
                                        gpointer         user_data);
